"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.behaveConverter = void 0;
var behaveConverter = function (json) {
    return {
        implementation: 'behave',
        features: json.map(behaveFeatureToFeature),
    };
};
exports.behaveConverter = behaveConverter;
function behaveFeatureToFeature(behaveFeature) {
    return {
        uri: getPath(behaveFeature.location),
        keyword: behaveFeature.keyword,
        name: behaveFeature.name,
        description: behaveFeature.description ? behaveFeature.description.join('') : '',
        elements: behaveFeature.elements.map(behaveElementToElement),
        tags: behaveFeature.tags.map(behaveTagToTag),
    };
}
function behaveTagToTag(behaveTag) {
    return { name: behaveTag };
}
function behaveElementToElement(behaveElement) {
    return {
        line: getLine(behaveElement.location),
        type: behaveElement.type,
        keyword: behaveElement.keyword,
        name: behaveElement.name,
        description: behaveElement.description ? behaveElement.description.join('') : '',
        steps: behaveElement.steps.map(behaveStepToStep),
    };
}
function behaveStepToStep(behaveStep) {
    return {
        keyword: behaveStep.keyword,
        name: behaveStep.name,
        line: getLine(behaveStep.location),
        result: behaveResultToResult(behaveStep.result),
    };
}
function behaveResultToResult(behaveResult) {
    if (!behaveResult)
        return { status: 'undefined' };
    return {
        status: behaveResult.status,
        error_message: behaveResult.error_message ? behaveResult.error_message.join('') : undefined,
        duration: behaveResult.duration,
    };
}
function getLine(location) {
    var match = /\w+:(\d+)/.exec(location);
    if (!match)
        throw new Error("Location ".concat(location, " does not follow <path>:<line> pattern"));
    return parseInt(match[1]);
}
function getPath(location) {
    var match = /(\w+):\d+/.exec(location);
    if (!match)
        throw new Error("Location ".concat(location, " does not follow <path>:<line> pattern"));
    return match[1];
}
//# sourceMappingURL=behaveConverter.js.map