"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cucumberJsConverter = void 0;
var cucumberJsConverter = function (json) {
    return {
        implementation: 'cucumber-js',
        features: json.map(jsFeatureToFeature),
    };
};
exports.cucumberJsConverter = cucumberJsConverter;
function jsFeatureToFeature(jsFeature) {
    return __assign(__assign({}, jsFeature), {
        elements: jsFeature.elements.map(jsElementToElement),
    });
}
function jsElementToElement(jsElement) {
    var before = jsElement.steps.filter(isBeforeHook).map(hookStepToHook);
    var steps = jsElement.steps.filter(isStep).map(jsStepToStep);
    var after = jsElement.steps.filter(isAfterHook).map(hookStepToHook);
    return {
        after: after,
        before: before,
        description: jsElement.description || '',
        id: jsElement.id,
        keyword: jsElement.keyword,
        line: jsElement.line,
        name: jsElement.name,
        steps: steps,
        tags: jsElement.tags,
        type: jsElement.type || 'scenario',
    };
}
function jsStepToStep(jsStep) {
    var docStrings = (jsStep.arguments || []).filter(isDocstring).map(function (docString) { return ({
        line: docString.line,
        value: docString.content,
    }); });
    var datatables = (jsStep.arguments || []).filter(isDataTable);
    return {
        keyword: jsStep.keyword,
        line: jsStep.line,
        name: jsStep.name,
        result: jsStep.result,
        match: jsStep.match,
        doc_string: docStrings.length > 0 ? docStrings[0] : undefined,
        rows: datatables.length > 0 ? datatables[0].rows : undefined,
    };
}
function hookStepToHook(jsHook) {
    return {
        result: jsHook.result,
    };
}
function isStep(jsStepOrHook) {
    return !('hidden' in jsStepOrHook);
}
function isBeforeHook(jsStepOrHook) {
    return 'hidden' in jsStepOrHook && jsStepOrHook.keyword === 'Before';
}
function isAfterHook(jsStepOrHook) {
    return 'hidden' in jsStepOrHook && jsStepOrHook.keyword === 'After';
}
function isDocstring(argument) {
    return argument.content !== undefined;
}
function isDataTable(argument) {
    return !isDocstring(argument);
}
//# sourceMappingURL=cucumberJsConverter.js.map