"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cucumberRubyConverter = void 0;
var cucumberRubyConverter = function (json) {
    return {
        implementation: 'cucumber-ruby',
        features: json.map(rubyFeatureToFeature),
    };
};
exports.cucumberRubyConverter = cucumberRubyConverter;
function rubyFeatureToFeature(feature) {
    var elements = feature.elements.map(rubyElementToElement);
    return {
        description: feature.description,
        elements: elements,
        id: feature.id,
        keyword: feature.keyword,
        line: feature.line,
        name: feature.name,
        tags: feature.tags || [],
        uri: feature.uri,
    };
}
function rubyElementToElement(rubyElement) {
    var before = (rubyElement.before || []).map(rubyHookToHook);
    var steps = rubyElement.steps.map(rubyStepToStep);
    var after = (rubyElement.after || []).map(rubyHookToHook);
    var type = rubyElement.type === 'scenario_outline' ? 'scenario' : rubyElement.type;
    return {
        type: type,
        before: before,
        steps: steps,
        after: after,
        id: rubyElement.id,
        keyword: rubyElement.keyword,
        line: rubyElement.line,
        name: rubyElement.name,
        tags: rubyElement.tags,
        description: rubyElement.description,
        start_timestamp: rubyElement.start_timestamp,
    };
}
function rubyHookToHook(rubyHook) {
    return {
        result: rubyHook.result,
        match: rubyMatchToMatch(rubyHook.match),
    };
}
function rubyMatchToMatch(rubyMatch) {
    return {
        location: rubyMatch.location,
    };
}
function rubyStepToStep(rubyStep) {
    var result = rubyStep.result || {
        status: 'unknown',
    };
    return {
        name: rubyStep.name,
        line: rubyStep.line,
        keyword: rubyStep.keyword,
        match: rubyStep.match ? rubyMatchToMatch(rubyStep.match) : undefined,
        result: result,
        doc_string: rubyStep.doc_string,
        rows: rubyStep.rows,
    };
}
//# sourceMappingURL=cucumberRubyConverter.js.map