"use strict";
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var e_1, _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.convert = exports.convertMulti = void 0;
var ajv_1 = __importDefault(require("ajv"));
var assert_1 = __importDefault(require("assert"));
var behaveConverter_js_1 = require("./behave/behaveConverter.js");
var BehaveSchema_js_1 = __importDefault(require("./behave/BehaveSchema.js"));
var cucumberJsConverter_js_1 = require("./cucumber-js/cucumberJsConverter.js");
var CucumberJsSchema_js_1 = __importDefault(require("./cucumber-js/CucumberJsSchema.js"));
var cucumberJvmConverter_js_1 = require("./cucumber-jvm/cucumberJvmConverter.js");
var CucumberJvmSchema_js_1 = __importDefault(require("./cucumber-jvm/CucumberJvmSchema.js"));
var cucumberRubyConverter_js_1 = require("./cucumber-ruby/cucumberRubyConverter.js");
var CucumberRubySchema_js_1 = __importDefault(require("./cucumber-ruby/CucumberRubySchema.js"));
var CucumberSchema_js_1 = __importDefault(require("./CucumberSchema.js"));
var implementationConverterBySchema = new Map();
implementationConverterBySchema.set(BehaveSchema_js_1.default, behaveConverter_js_1.behaveConverter);
implementationConverterBySchema.set(CucumberJsSchema_js_1.default, cucumberJsConverter_js_1.cucumberJsConverter);
implementationConverterBySchema.set(CucumberJvmSchema_js_1.default, cucumberJvmConverter_js_1.cucumberJvmConverter);
implementationConverterBySchema.set(CucumberRubySchema_js_1.default, cucumberRubyConverter_js_1.cucumberRubyConverter);
var resultValidator = new ajv_1.default().compile(CucumberSchema_js_1.default);
var convalidators = [];
var _loop_1 = function (implementationSchema, converter) {
    var implementationValidator = new ajv_1.default().compile(implementationSchema);
    var resultValidatingConverter = function (obj) {
        var converted = converter(obj);
        if (resultValidator(converted)) {
            return converted;
        }
        else {
            var error = "Error from ".concat(implementationSchema.$ref, " validation: ").concat(JSON.stringify(resultValidator.errors, null, 2));
            var convertedJson = JSON.stringify(converted, null, 2);
            throw new Error("Could not validate converted Cucumber JSON.\n".concat(error, "\nConverted JSON:").concat(convertedJson));
        }
    };
    convalidators.push({
        implementationValidator: implementationValidator,
        converter: resultValidatingConverter,
        schema: implementationSchema,
    });
};
try {
    for (var _b = __values(implementationConverterBySchema.entries()), _c = _b.next(); !_c.done; _c = _b.next()) {
        var _d = __read(_c.value, 2), implementationSchema = _d[0], converter = _d[1];
        _loop_1(implementationSchema, converter);
    }
}
catch (e_1_1) { e_1 = { error: e_1_1 }; }
finally {
    try {
        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
    }
    finally { if (e_1) throw e_1.error; }
}
function convertMulti(data) {
    var errors = [];
    var candidateConvalidators = convalidators.filter(function (convalidator) {
        var validator = convalidator.implementationValidator;
        var schema = convalidator.schema;
        if (validator(data)) {
            return true;
        }
        else {
            var error = "Errors from ".concat(schema.$ref, " validation: ").concat(JSON.stringify(validator.errors, null, 2));
            // console.log(error)
            errors.push(error);
        }
    });
    if (candidateConvalidators.length === 0) {
        throw new Error("Could not validate Cucumber JSON.\n".concat(errors.join('\n')));
    }
    return candidateConvalidators.map(function (convalidator) { return convalidator.converter(data); });
}
exports.convertMulti = convertMulti;
function convert(data) {
    var cucumberJsons = convertMulti(data);
    if (cucumberJsons.length > 1) {
        // Sanity check that all the conversions have the same result
        for (var n = 1; n < cucumberJsons.length; n++) {
            var cucumberJson1 = cucumberJsons[n - 1];
            var cucumberJson2 = cucumberJsons[n];
            assert_1.default.deepStrictEqual(withoutImplementation(cucumberJson1), withoutImplementation(cucumberJson2), "The platform-specifc Cucumber JSON was valid against multiple JSON schemas, and wasn't consistently converted");
        }
    }
    return cucumberJsons[0];
}
exports.convert = convert;
function withoutImplementation(cucumberJson) {
    var copy = JSON.parse(JSON.stringify(cucumberJson));
    copy.implementation = '';
    return copy;
}
//# sourceMappingURL=index.js.map