export const cucumberJvmConverter = (json) => {
    return {
        implementation: 'cucumber-jvm',
        features: json.map(jvmFeatureToFeature),
    };
};
function jvmFeatureToFeature(feature) {
    const tags = (feature.tags || []).map(locationTagToTag);
    const elements = feature.elements.map(jvmElementToElement);
    return {
        description: feature.description,
        elements,
        id: feature.id,
        keyword: feature.keyword,
        line: feature.line,
        name: feature.name,
        tags,
        uri: feature.uri,
    };
}
function locationTagToTag(locationTag) {
    return {
        name: locationTag.name,
        line: locationTag.location.line,
    };
}
function jvmElementToElement(jvmElement) {
    const before = (jvmElement.before || []).map(jvmHookToHook);
    const steps = jvmElement.steps.map(jvmStepToStep);
    const after = (jvmElement.after || []).map(jvmHookToHook);
    return Object.assign(Object.assign({}, jvmElement), {
        before,
        steps,
        after,
    });
}
function jvmHookToHook(jvmHook) {
    return {
        result: jvmHook.result,
        match: jvmMatchToMatch(jvmHook.match),
    };
}
function jvmMatchToMatch(jvmMatch) {
    return {
        location: jvmMatch.location,
    };
    // return {
    //   ...jvmMatch,
    //   ...{
    //     arguments: (jvmMatch.arguments || []).map((arg) => ({
    //       value: arg.val,
    //       offset: arg.offset,
    //     })),
    //   },
    // }
}
function jvmStepToStep(jvmStep) {
    return Object.assign(Object.assign({}, jvmStep), {
        match: jvmStep.match ? jvmMatchToMatch(jvmStep.match) : undefined,
    });
}
//# sourceMappingURL=cucumberJvmConverter.js.map