var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Ajv from 'ajv';
import fs from 'fs';
import { promisify } from 'util';
import { behaveConverter } from './behave/1/behaveConverter.js';
import { cucumberJsConverter } from './cucumber-js/7/cucumberJsConverter.js';
import { cucumberJvmConverter } from './cucumber-jvm/7/cucumberJvmConverter.js';
import { cucumberRubyConverter } from './cucumber-ruby/7/cucumberRubyConverter.js';
const readFile = promisify(fs.readFile);
const implementationConverterByPath = {
    'src/behave/1/BehaveJson.json': behaveConverter,
    'src/cucumber-js/7/CucumberJsJson.json': cucumberJsConverter,
    'src/cucumber-ruby/7/CucumberRubyJson.json': cucumberRubyConverter,
    'src/cucumber-jvm/7/CucumberJvmJson.json': cucumberJvmConverter,
};
export function makeConverter() {
    return __awaiter(this, void 0, void 0, function* () {
        const implementationSchemaFiles = Object.keys(implementationConverterByPath);
        const resultSchemaFile = 'src/CucumberJson.json';
        const resultSchema = yield readFile(resultSchemaFile, 'utf-8');
        const resultValidator = new Ajv().compile(JSON.parse(resultSchema));
        const implementationSchemas = yield Promise.all(implementationSchemaFiles.map((json) => readFile(json, 'utf-8')));
        const convalidators = implementationSchemaFiles.map((schemaFile, i) => {
            const implementationSchema = implementationSchemas[i];
            const implementationValidator = new Ajv().compile(JSON.parse(implementationSchema));
            const converter = implementationConverterByPath[schemaFile];
            if (!converter)
                throw new Error(`No converter for ${schemaFile}`);
            const resultValidatingConverter = (obj) => {
                const converted = converter(obj);
                if (resultValidator(converted)) {
                    return converted;
                }
                else {
                    const error = `Error from ${resultSchemaFile} validation: ${JSON.stringify(resultValidator.errors, null, 2)}`;
                    const convertedJson = JSON.stringify(converted, null, 2);
                    throw new Error(`Could not validate converted Cucumber JSON.\n${error}\nConverted JSON:${convertedJson}`);
                }
            };
            return { implementationValidator, converter: resultValidatingConverter, schemaFile };
        });
        return (data) => {
            const errors = [];
            const candidateConvalidators = convalidators.filter((convalidator) => {
                const validator = convalidator.implementationValidator;
                const schemaFile = convalidator.schemaFile;
                if (validator(data)) {
                    return true;
                }
                else {
                    const error = `Errors from ${schemaFile} validation: ${JSON.stringify(validator.errors, null, 2)}`;
                    // console.log(error)
                    errors.push(error);
                }
            });
            if (candidateConvalidators.length === 0) {
                throw new Error(`Could not validate Cucumber JSON.\n${errors.join('\n')}`);
            }
            return candidateConvalidators.map((convalidator) => convalidator.converter(data));
        };
    });
}
//# sourceMappingURL=makeConverter.js.map